<?php
// core/MikroTikAPI.php

// Include Composer's autoloader
require_once __DIR__ . '/../vendor/autoload.php';

use RouterOS\Client;
use RouterOS\Query;

class MikroTikAPI {
    private $client;
    private $connected = false;

    public function __construct($host, $user, $pass, $port = 8728) {
        $this->client = new Client([
            'host' => $host,
            'user' => $user,
            'pass' => $pass,
            'port' => $port,
            'timeout' => 5, // seconds
        ]);
    }

    public function connect() {
        try {
            $this->client->connect();
            $this->connected = true;
            return true;
        } catch (\Exception $e) {
            // Optionally log the error message: $e->getMessage()
            $this->connected = false;
            return false;
        }
    }

    public function disconnect() {
        // Check if the underlying client has a disconnect method
        if (method_exists($this->client, 'disconnect')) {
            $this->client->disconnect();
        }
        $this->connected = false;
    }

    public function getStatus() {
        if (!$this->connected) return [];
        try {
            $query = new Query('/system/resource/print');
            $response = $this->client->query($query)->read();
            if (isset($response[0])) {
                $data = $response[0];
                return [
                    'uptime'      => $data['uptime'] ?? 'N/A',
                    'ram'         => (isset($data['free-memory']) && isset($data['total-memory']))
                                     ? $data['free-memory'] . ' free of ' . $data['total-memory']
                                     : 'N/A',
                    'storage'     => (isset($data['free-hdd-space']) && isset($data['total-hdd-space']))
                                     ? $data['free-hdd-space'] . ' free of ' . $data['total-hdd-space']
                                     : 'N/A',
                    'cpu_load'    => $data['cpu-load'] ?? 'N/A',
                    'temperature' => $data['temperature'] ?? 'N/A',
                    'board_name'  => $data['board-name'] ?? 'N/A'
                ];
            }
        } catch (\Exception $e) {
            // Optionally log error message: $e->getMessage()
        }
        return [];
    }

    public function getLiveTraffic($interface = 'LAN2-ISP2') {
        if (!$this->connected) return [];
        try {
            $query = new Query('/interface/monitor-traffic');
            $query->equal('interface', $interface);
            $query->equal('once'); // Return data only once
            $response = $this->client->query($query)->read();
            if (isset($response[0])) {
                return [
                    'rx' => $response[0]['rx-rate'] ?? 'N/A',
                    'tx' => $response[0]['tx-rate'] ?? 'N/A'
                ];
            }
        } catch (\Exception $e) {
            // Optionally log error message: $e->getMessage()
        }
        return [];
    }
    public function getActiveHotspotUsers() {
        if (!$this->connected) return [];
        try {
            $query = new Query('/ip/hotspot/active/print');
            $response = $this->client->query($query)->read();
            return $response;
        } catch (\Exception $e) {
            return [];
        }
    }

    public function getRecentRouterActivity($limit = 10) {
        if (!$this->connected) {
            return [];
        }
        try {
            $query = new \RouterOS\Query('/log/print');
            // Remove the ->limit() call since it's not available.
            $response = $this->client->query($query)->read();
            // Return only the first $limit entries
            return array_slice($response, 0, $limit);
        } catch (\Exception $e) {
            // Optionally log the error: $e->getMessage()
            return [];
        }
    }    
    
    

    
}
?>
